Link Configurations
===================


 .. autoclass:: squidasm.run.stack.config.LinkConfig
    :members:
    :undoc-members:
    :member-order: bysource


 .. autoclass:: squidasm.run.stack.config.DepolariseLinkConfig
    :members:
    :undoc-members:
    :member-order: bysource

 .. autoclass:: squidasm.run.stack.config.HeraldedLinkConfig
    :members:
    :undoc-members:
    :member-order: bysource